@@ -1,9 +1,8 @@
 def findDistroType():
-    systemType = "unknown"
     try:
         open("/etc/debian_version").read()
-        systemType = "debian"
+        return "debian"
     except Exception:
         pass
 
-    return systemType
\ No newline at end of file
+    return "unknown"
\ No newline at end of file
